@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 
 #include <core/crypthelper.h>
@@ -271,8 +284,7 @@ CryptHelper::AES128Encrypt(const unsigned char *keyData, unsigned keySize, const
 		BytesToKey(keyData, keySize, key, iv);
 		// Add padding to plain data.
 		unsigned paddedPlainSize = ADD_PADDING(plainSize);
-		unsigned char *paddedPlainStr = new unsigned char[ADD_PADDING(plainSize)];
-		memset(paddedPlainStr, 0, paddedPlainSize);
+		unsigned char *paddedPlainStr = (unsigned char *)calloc(paddedPlainSize, 1);
 		memcpy(paddedPlainStr, plainStr.c_str(), plainSize);
 		// Perform the encryption.
 		int cipherSize = paddedPlainSize;
@@ -311,7 +323,7 @@ CryptHelper::AES128Encrypt(const unsigned char *keyData, unsigned keySize, const
 
 		gcry_cipher_close(hd);
 #endif
-		delete[] paddedPlainStr;
+		free(paddedPlainStr);
 	}
 	return retVal;
 }
