@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 
 #include "localboard.h"
@@ -95,6 +108,8 @@ void LocalBoard::distributePot()
 	// temp var
 	int highestCardsValue;
 	size_t winnerCount;
+	bool finalPot;
+	int potCarryOver = 0;
 	size_t mod;
 	bool winnerHit;
 
@@ -111,7 +126,7 @@ void LocalBoard::distributePot()
 			potLevel.push_back(playerSetsSort[i]);
 
 			// level sum
-			potLevel.push_back((playerSetsSort.size()-i)*potLevel[0]);
+			potLevel.push_back((playerSetsSort.size()-i)*potLevel[0] + potCarryOver);
 
 			// determine level highestCardsValue
 			for(it_c=seatsList->begin(), j=0; it_c!=seatsList->end(); ++it_c,j++) {
@@ -133,71 +148,94 @@ void LocalBoard::distributePot()
 				throw LocalException(__FILE__, __LINE__, ERR_NO_WINNER);
 			}
 
-			// distribute the pot level sum to level winners
-			mod = (potLevel[1])%winnerCount;
-			// pot level sum divisible by winnerCount
-			if(mod == 0) {
+			// check if this is the final pot level for at least one winner
+			finalPot = false;
+			for(j=2; j<potLevel.size(); j++) {
+				// find seat with potLevel[j]-ID
+				for(it=seatsList->begin(), k=0; it!=seatsList->end(); ++it, k++) {
+					if((*it)->getMyUniqueID() == potLevel[j] && potLevel[0] == playerSets[k]) {
+						finalPot = true;
+						break;
+					}
+				}
+				if(finalPot) break;
+			}
 
-				for(j=2; j<potLevel.size(); j++) {
-					// find seat with potLevel[j]-ID
+			if(finalPot) {
+				// distribute the pot level sum to level winners
+				mod = (potLevel[1])%winnerCount;
+				// pot level sum divisible by winnerCount
+				if(mod == 0) {
+
+					for(j=2; j<potLevel.size(); j++) {
+						// find seat with potLevel[j]-ID
+						for(it=seatsList->begin(); it!=seatsList->end(); ++it) {
+							if((*it)->getMyUniqueID() == potLevel[j]) {
+								break;
+							}
+						}
+						if(it == seatsList->end()) {
+							throw LocalException(__FILE__, __LINE__, ERR_SEAT_NOT_FOUND);
+						}
+						(*it)->setMyCash( (*it)->getMyCash() + ((potLevel[1])/winnerCount));
+
+						// filling winners vector
+						winners.push_back((*it)->getMyUniqueID());
+						(*it)->setLastMoneyWon( (*it)->getLastMoneyWon() + (potLevel[1])/winnerCount );
+					}
+
+				}
+				// pot level sum not divisible by winnerCount
+				// --> distribution after smallBlind
+				else {
+
+					// find Seat with dealerPosition
 					for(it=seatsList->begin(); it!=seatsList->end(); ++it) {
-						if((*it)->getMyUniqueID() == potLevel[j]) {
+						if((*it)->getMyUniqueID() == dealerPosition) {
 							break;
 						}
 					}
 					if(it == seatsList->end()) {
 						throw LocalException(__FILE__, __LINE__, ERR_SEAT_NOT_FOUND);
 					}
-					(*it)->setMyCash( (*it)->getMyCash() + ((potLevel[1])/winnerCount));
 
-					// filling winners vector
-					winners.push_back((*it)->getMyUniqueID());
-					(*it)->setLastMoneyWon( (*it)->getLastMoneyWon() + (potLevel[1])/winnerCount );
-				}
+					for(j=0; j<winnerCount; j++) {
 
-			}
-			// pot level sum not divisible by winnerCount
-			// --> distribution after smallBlind
-			else {
+						winnerHit = false;
 
-				// find Seat with dealerPosition
-				for(it=seatsList->begin(); it!=seatsList->end(); ++it) {
-					if((*it)->getMyUniqueID() == dealerPosition) {
-						break;
-					}
-				}
-				if(it == seatsList->end()) {
-					throw LocalException(__FILE__, __LINE__, ERR_SEAT_NOT_FOUND);
-				}
+						for(k=0; k<MAX_NUMBER_OF_PLAYERS && !winnerHit; k++) {
 
-				for(j=0; j<winnerCount; j++) {
+							++it;
+							if(it == seatsList->end())
+								it = seatsList->begin();
 
-					winnerHit = false;
+							for(l=2; l<potLevel.size(); l++) {
+								if((*it)->getMyActiveStatus() && (*it)->getMyUniqueID() == potLevel[l])
+									winnerHit = true;
+							}
 
-					for(k=0; k<MAX_NUMBER_OF_PLAYERS && !winnerHit; k++) {
-
-						++it;
-						if(it == seatsList->end())
-							it = seatsList->begin();
-
-						for(l=2; l<potLevel.size(); l++) {
-							if((*it)->getMyUniqueID() == potLevel[l]) winnerHit = true;
 						}
 
-					}
-
-					if(j<mod) {
-						(*it)->setMyCash( (*it)->getMyCash() + (int)((potLevel[1])/winnerCount) + 1);
-						// filling winners vector
-						winners.push_back((*it)->getMyUniqueID());
-						(*it)->setLastMoneyWon( (*it)->getLastMoneyWon() + ((potLevel[1])/winnerCount) + 1 );
-					} else {
-						(*it)->setMyCash( (*it)->getMyCash() + (int)((potLevel[1])/winnerCount));
-						// filling winners vector
-						winners.push_back((*it)->getMyUniqueID());
-						(*it)->setLastMoneyWon( (*it)->getLastMoneyWon() + (potLevel[1])/winnerCount );
+						if(j<mod) {
+							(*it)->setMyCash( (*it)->getMyCash() + (int)((potLevel[1])/winnerCount) + 1);
+							// filling winners vector
+							winners.push_back((*it)->getMyUniqueID());
+							(*it)->setLastMoneyWon( (*it)->getLastMoneyWon() + ((potLevel[1])/winnerCount) + 1 );
+						} else {
+							(*it)->setMyCash( (*it)->getMyCash() + (int)((potLevel[1])/winnerCount));
+							// filling winners vector
+							winners.push_back((*it)->getMyUniqueID());
+							(*it)->setLastMoneyWon( (*it)->getLastMoneyWon() + (potLevel[1])/winnerCount );
+						}
 					}
 				}
+				potCarryOver = 0;
+
+				// pot refresh
+				pot -= potLevel[1];
+
+			} else {
+				potCarryOver = potLevel[1];
 			}
 
 			// reevaluate the player sets
@@ -211,9 +249,6 @@ void LocalBoard::distributePot()
 			playerSetsSort = playerSets;
 			sort(playerSetsSort.begin(), playerSetsSort.end());
 
-			// pot refresh
-			pot -= potLevel[1];
-
 			// clear potLevel
 			potLevel.clear();
 
