@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 
 #include "localhand.h"
@@ -405,7 +418,6 @@ void LocalHand::assignButtons()
 
 	size_t i;
 	PlayerListIterator it;
-	PlayerListConstIterator it_c;
 
 	// delete all buttons
 	for (it=seatsList->begin(); it!=seatsList->end(); ++it) {
@@ -491,7 +503,7 @@ void LocalHand::setBlinds()
 
 				(*it_c)->setMySet((*it_c)->getMyCash());
 				// 1 to do not log this
-				(*it_c)->setMyAction(PLAYER_ACTION_ALLIN,1);
+				(*it_c)->setMyAction(PLAYER_ACTION_ALLIN);
 
 			} else {
 				(*it_c)->setMySet(smallBlind);
@@ -511,7 +523,7 @@ void LocalHand::setBlinds()
 
 				(*it_c)->setMySet((*it_c)->getMyCash());
 				// 1 to do not log this
-				(*it_c)->setMyAction(PLAYER_ACTION_ALLIN,1);
+				(*it_c)->setMyAction(PLAYER_ACTION_ALLIN);
 
 			} else {
 				(*it_c)->setMySet(2*smallBlind);
@@ -527,7 +539,7 @@ void LocalHand::switchRounds()
 	// logging last player action
 	PlayerListConstIterator previousPlayerIt = getRunningPlayerIt(previousPlayerID);
 	if(previousPlayerIt != runningPlayerList->end()) {
-		if(myLog) myLog->logPlayerAction((*previousPlayerIt)->getMyName(),myLog->transformPlayerActionLog((*previousPlayerIt)->getMyAction()),(*previousPlayerIt)->getMySet());
+		if(myLog) myLog->logPlayerAction((*previousPlayerIt)->getMyName(),myLog->transformPlayerActionLog((*previousPlayerIt)->getMyAction()),(*previousPlayerIt)->getMyLastRelativeSet());
 	}
 
 	PlayerListIterator it, it_1;
