@@ -38,15 +38,15 @@
 #define MAX_GUI_SPEED			11
 
 #define DEBUG_MODE			0
-#define SQLITE_LOG          1
-#define HTML_LOG            0
+#define SQLITE_LOG			1
+#define HTML_LOG			0
 
 #define POKERTH_VERSION_MAJOR	1
-#define POKERTH_VERSION_MINOR	01
+#define POKERTH_VERSION_MINOR	11
 #define POKERTH_VERSION			((POKERTH_VERSION_MAJOR << 8) | POKERTH_VERSION_MINOR)
 
 #define POKERTH_BETA_REVISION	0
-#define POKERTH_BETA_RELEASE_STRING	 "1.0.1"
+#define POKERTH_BETA_RELEASE_STRING	 "1.1.1"
 
 #define SQLITE_LOG_VERSION		1
 
@@ -64,7 +64,10 @@ enum ServerMode {
 enum ServerTransportProtocol {
 	TRANSPORT_PROTOCOL_TCP = 1,
 	TRANSPORT_PROTOCOL_SCTP = 2,
-	TRANSPORT_PROTOCOL_TCP_SCTP = 3
+	TRANSPORT_PROTOCOL_TCP_SCTP = 3,
+	TRANSPORT_PROTOCOL_WEBSOCKET = 4,
+	TRANSPORT_PROTOCOL_TCP_WEBSOCKET = 5,
+	TRANSPORT_PROTOCOL_TCP_SCTP_WEBSOCKET = 7
 };
 
 enum GameState {
@@ -176,16 +179,4 @@ enum NetTimeoutReason {
 	NETWORK_TIMEOUT_KICK_AFTER_AUTOFOLD
 };
 
-struct ServerStats {
-	ServerStats()
-		: numberOfPlayersOnServer(0), numberOfGamesOpen(0), totalPlayersEverLoggedIn(0),
-		  totalGamesEverCreated(0), maxGamesOpen(0), maxPlayersLoggedIn(0) {}
-	unsigned numberOfPlayersOnServer;
-	unsigned numberOfGamesOpen;
-	unsigned totalPlayersEverLoggedIn;
-	unsigned totalGamesEverCreated;
-	unsigned maxGamesOpen;
-	unsigned maxPlayersLoggedIn;
-};
-
 #endif
