@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 /* Game data. */
 
@@ -22,8 +35,9 @@
 
 #include <list>
 #include <string>
+#ifndef Q_MOC_RUN
 #include <third_party/boost/timers.hpp>
-
+#endif
 
 typedef std::list<unsigned> PlayerIdList;
 
@@ -58,13 +72,14 @@ enum AfterManualBlindsMode {
 
 // For the sake of simplicity, this is a struct.
 struct GameData {
-	GameData() : gameType(GAME_TYPE_NORMAL), maxNumberOfPlayers(0), startMoney(0),
-		firstSmallBlind(0), raiseIntervalMode(RAISE_ON_HANDNUMBER),
-		raiseSmallBlindEveryHandsValue(8), raiseSmallBlindEveryMinutesValue(1),
-		raiseMode(DOUBLE_BLINDS), afterManualBlindsMode(AFTERMB_DOUBLE_BLINDS),
-		afterMBAlwaysRaiseValue(0), guiSpeed(4), delayBetweenHandsSec(6),
-		playerActionTimeoutSec(20) {}
+	GameData() : gameType(GAME_TYPE_NORMAL), allowSpectators(true),
+		maxNumberOfPlayers(0), startMoney(0), firstSmallBlind(0),
+		raiseIntervalMode(RAISE_ON_HANDNUMBER), raiseSmallBlindEveryHandsValue(8),
+		raiseSmallBlindEveryMinutesValue(1), raiseMode(DOUBLE_BLINDS),
+		afterManualBlindsMode(AFTERMB_DOUBLE_BLINDS), afterMBAlwaysRaiseValue(0),
+		guiSpeed(4), delayBetweenHandsSec(6), playerActionTimeoutSec(20) {}
 	GameType gameType;
+	bool allowSpectators;
 	int maxNumberOfPlayers;
 	int startMoney;
 	int firstSmallBlind;
@@ -87,6 +102,8 @@ struct GameInfo {
 	GameMode mode;
 	unsigned adminPlayerId;
 	PlayerIdList players;
+	PlayerIdList spectators;
+	PlayerIdList spectatorsDuringGame;
 	bool isPasswordProtected;
 };
 
