@@ -33,6 +33,9 @@
 
 #include <string>
 #include <QtCore>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 #include <QtGui>
 #include <boost/shared_ptr.hpp>
 
