@@ -35,6 +35,9 @@
 
 #include <QtGui>
 #include <QtCore>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 
 class gameTableImpl;
 
