@@ -35,7 +35,12 @@
 
 #include <QtGui>
 #include <QtCore>
+#ifndef Q_MOC_RUN
 #include <third_party/boost/timers.hpp>
+#endif
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 
 class gameTableImpl;
 
