@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #ifndef NEWGAMEDIALOGIMPL_H
 #define NEWGAMEDIALOGIMPL_H
@@ -26,7 +39,9 @@
 
 #include <QtGui>
 #include <QtCore>
-
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 
 class ConfigFile;
 class changeCompleteBlindsDialogImpl;
@@ -37,11 +52,13 @@ class newGameDialogImpl: public QDialog, public Ui::newGameDialog
 public:
 	newGameDialogImpl(QMainWindow *parent = 0, ConfigFile* = 0);
 
-	void exec();
+	int exec();
 	changeCompleteBlindsDialogImpl* getChangeCompleteBlindsDialog() {
 		return myChangeCompleteBlindsDialog;
 	}
 
+	bool eventFilter(QObject *obj, QEvent *event);
+
 public slots:
 
 	void callChangeBlindsDialog(bool);
