@@ -33,6 +33,9 @@
 
 #include <QtGui>
 #include <QtCore>
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
 
 class MyStyleListItem : public QTreeWidgetItem
 {
