@@ -55,6 +55,7 @@ settingsDialogImpl::settingsDialogImpl(QWidget *parent, ConfigFile *c, selectAva
 	label_soundvol->hide();
 	label_soundVolume->hide();
 	horizontalSlider_soundVolume->hide();
+	this->setWindowState(Qt::WindowFullScreen);
 #endif
 
 	myManualBlindsOrderDialog = new manualBlindsOrderDialogImpl;
@@ -65,7 +66,7 @@ settingsDialogImpl::settingsDialogImpl(QWidget *parent, ConfigFile *c, selectAva
 	pushButton_openLogDir->setIcon(QIcon(QPixmap(myAppDataPath+"gfx/gui/misc/fileopen16.png")));
 
 	if (myConfig->readConfigInt("CLA_NoWriteAccess")) {
-		groupBox_logOnOff->setDisabled(TRUE);
+		groupBox_logOnOff->setDisabled(true);
 	}
 
 	comboBox_switchLanguage->addItem(QString(tr("Afrikaans")+" "+QString::fromUtf8("(Afrikaans)")),"af");
@@ -96,6 +97,7 @@ settingsDialogImpl::settingsDialogImpl(QWidget *parent, ConfigFile *c, selectAva
 	comboBox_switchLanguage->addItem(QString(tr("Swedish")+" "+QString::fromUtf8("(svenska)")),"sv");
 	comboBox_switchLanguage->addItem(QString(tr("Tamil")+" "+QString::fromUtf8("(தமிழ்)")),"ta");
 	comboBox_switchLanguage->addItem(QString(tr("Turkish")+" "+QString::fromUtf8("(Tϋrkçe)")),"tr");
+	comboBox_switchLanguage->addItem(QString(tr("Vietnamese")+" "+QString::fromUtf8("(Tiếng Việt)")),"vi");
 
 #ifdef GUI_800x480
 	connect( pushButton_ok, SIGNAL( clicked() ), this, SLOT( isAccepted() ) );
@@ -164,7 +166,7 @@ settingsDialogImpl::~settingsDialogImpl()
 
 void settingsDialogImpl::prepareDialog()
 {
-	playerNickIsChanged = FALSE;
+	playerNickIsChanged = false;
 
 	//Player Nicks
 	lineEdit_HumanPlayerName->setText(QString::fromUtf8(myConfig->readConfigString("MyName").c_str()));
@@ -246,23 +248,23 @@ void settingsDialogImpl::prepareDialog()
 	if(myConfig->readConfigInt("UseAvatarServer")) {
 		lineEdit_avatarServerAddress->setText(QString::fromUtf8(myConfig->readConfigString("AvatarServerAddress").c_str()));
 		checkBox_useAvatarServer->setCheckState(Qt::Checked);
-		lineEdit_avatarServerAddress->setEnabled(TRUE);
+		lineEdit_avatarServerAddress->setEnabled(true);
 	} else {
 		checkBox_useAvatarServer->setCheckState(Qt::Unchecked);
-		lineEdit_avatarServerAddress->setEnabled(FALSE);
+		lineEdit_avatarServerAddress->setEnabled(false);
 	}
 	checkBox_UseInternetGamePassword->setChecked(myConfig->readConfigInt("UseInternetGamePassword"));
 	if(myConfig->readConfigInt("UseInternetGamePassword")) {
 		lineEdit_InternetGamePassword->setText(QString::fromUtf8(myConfig->readConfigString("InternetGamePassword").c_str()));
 	}
 	checkBox_UseLobbyChat->setChecked(myConfig->readConfigInt("UseLobbyChat"));
-	checkBox_InetGane_AutoLeaveTheTableAfterGameFinished->setChecked(myConfig->readConfigInt("NetAutoLeaveGameAfterFinish"));
+	checkBox_InetGame_AutoLeaveTheTableAfterGameFinished->setChecked(myConfig->readConfigInt("NetAutoLeaveGameAfterFinish"));
 	comboBox_internetGameType->setCurrentIndex(myConfig->readConfigInt("InternetGameType"));
 	lineEdit_internetGameName->setText(QString::fromUtf8(myConfig->readConfigString("InternetGameName").c_str()));
 	if(myConfig->readConfigInt("InternetServerConfigMode")) {
-		groupBox_manualServerConfig->setChecked(TRUE);
+		groupBox_manualServerConfig->setChecked(true);
 	} else {
-		groupBox_automaticServerConfig->setChecked(TRUE);
+		groupBox_automaticServerConfig->setChecked(true);
 	}
 
 	std::list<std::string> playerIgnoreList = myConfig->readConfigStringList("PlayerIgnoreList");
@@ -272,6 +274,7 @@ void settingsDialogImpl::prepareDialog()
 		QTreeWidgetItem *item = new QTreeWidgetItem(treeWidget_internetGameIgnoredPlayers);
 		item->setText(0, QString::fromUtf8(it5->c_str()));
 	}
+	checkBox_allowSpectators->setChecked(myConfig->readConfigInt("InternetGameAllowSpectators"));
 
 	//Interface
 	comboBox_switchLanguage->setCurrentIndex(comboBox_switchLanguage->findData(QString::fromUtf8(myConfig->readConfigString("Language").c_str()).section('_', 0, 0)));
@@ -284,12 +287,16 @@ void settingsDialogImpl::prepareDialog()
 	checkBox_showFlipCardsAnimation->setChecked(myConfig->readConfigInt("ShowFlipCardsAnimation"));
 	checkBox_showBlindButtons->setChecked(myConfig->readConfigInt("ShowBlindButtons"));
 	checkBox_showCountryFlagInAvatar->setChecked(myConfig->readConfigInt("ShowCountryFlagInAvatar"));
+	checkBox_showPingStateInAvatar->setChecked(myConfig->readConfigInt("ShowPingStateInAvatar"));
 	checkBox_antiPeekMode->setChecked(myConfig->readConfigInt("AntiPeekMode"));
 	checkBox_enableBetInputFocusSwitch->setChecked(myConfig->readConfigInt("EnableBetInputFocusSwitch"));
 	checkBox_cardsChanceMonitor->setChecked(myConfig->readConfigInt("ShowCardsChanceMonitor"));
 	checkBox_dontTranslatePokerStrings->setChecked(myConfig->readConfigInt("DontTranslateInternationalPokerStringsFromStyle"));
 	checkBox_disableSplashscreen->setChecked(myConfig->readConfigInt("DisableSplashScreenOnStartup"));
 	checkBox_enableAccidentallyCallBlocker->setChecked(myConfig->readConfigInt("AccidentallyCallBlocker"));
+	checkBox_dontHideAvatarsOfIgnored->setChecked(myConfig->readConfigInt("DontHideAvatarsOfIgnored"));
+	checkBox_disableChatEmoticons->setChecked(myConfig->readConfigInt("DisableChatEmoticons"));
+
 
 	//S t y l e
 	//TABLE
@@ -375,13 +382,13 @@ void settingsDialogImpl::prepareDialog()
 	currentGameTableStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("CurrentGameTableStyle").c_str()));
 	if(currentGameTableStyle.getLoadedSuccessfull()) {
 		int i;
-		bool currentGameTableFound(FALSE);
+		bool currentGameTableFound(false);
 		for(i=0; i < treeWidget_gameTableStyles->topLevelItemCount(); i++) {
 			QTreeWidgetItem *item = treeWidget_gameTableStyles->topLevelItem(i);
 			if(item->data(0, 15) == currentGameTableStyle.getCurrentFileName()) {
 				item->setIcon(0, QIcon(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"/gfx/gui/misc/rating.png"));
 				treeWidget_gameTableStyles->setCurrentItem(item);
-				currentGameTableFound=TRUE;
+				currentGameTableFound=true;
 			} else item->setIcon(0, QIcon());
 		}
 		if(!currentGameTableFound) {
@@ -476,13 +483,13 @@ void settingsDialogImpl::prepareDialog()
 	currentCardDeckStyle.readStyleFile(QString::fromUtf8(myConfig->readConfigString("CurrentCardDeckStyle").c_str()));
 	if(currentCardDeckStyle.getLoadedSuccessfull()) {
 		int j;
-		bool currentCardDeckFound(FALSE);
+		bool currentCardDeckFound(false);
 		for(j=0; j < treeWidget_cardDeckStyles->topLevelItemCount(); j++) {
 			QTreeWidgetItem *item = treeWidget_cardDeckStyles->topLevelItem(j);
 			if(item->data(0, 15) == currentCardDeckStyle.getCurrentFileName()) {
 				item->setIcon(0, QIcon(QString::fromUtf8(myConfig->readConfigString("AppDataDir").c_str())+"/gfx/gui/misc/rating.png"));
 				treeWidget_cardDeckStyles->setCurrentItem(item);
-				currentCardDeckFound=TRUE;
+				currentCardDeckFound=true;
 			} else item->setIcon(0, QIcon());
 		}
 		if(!currentCardDeckFound) {
@@ -517,8 +524,8 @@ void settingsDialogImpl::prepareDialog()
 	radioButton_flipsideTux->setChecked(myConfig->readConfigInt("FlipsideTux"));
 	radioButton_flipsideOwn->setChecked(myConfig->readConfigInt("FlipsideOwn"));
 	if(radioButton_flipsideOwn->isChecked()) {
-		lineEdit_OwnFlipsideFilename->setEnabled(TRUE);
-		pushButton_openFlipsidePicture->setEnabled(TRUE);
+		lineEdit_OwnFlipsideFilename->setEnabled(true);
+		pushButton_openFlipsidePicture->setEnabled(true);
 	}
 	lineEdit_OwnFlipsideFilename->setText(QString::fromUtf8(myConfig->readConfigString("FlipsideOwnFile").c_str()));
 
@@ -560,7 +567,7 @@ void settingsDialogImpl::prepareDialog()
 	setFirstSmallBlindMargin();
 
 	//set this AFTER switch combobox like config-settings. This IS a currentIndexChanged() ;-)
-	languageIsChanged = FALSE;
+	languageIsChanged = false;
 
 	//disable reset config button when dialog is called from ingame
 	if(calledIngame) {
@@ -583,7 +590,7 @@ void settingsDialogImpl::exec(bool in_game)
 void settingsDialogImpl::isAccepted()
 {
 
-	settingsCorrect = TRUE;
+	settingsCorrect = true;
 
 	// 	Player Nicks
 	//check if all player nicks are unique --> otherwise dont save
@@ -604,7 +611,7 @@ void settingsDialogImpl::isAccepted()
 							  tr("The opponent names are not unique.\n"
 								 "Please choose different names for each Opponent!"),
 							  QMessageBox::Ok);
-		settingsCorrect = FALSE;
+		settingsCorrect = false;
 	} else {
 		//save nicks and avatars
 		myConfig->writeConfigString("MyName", lineEdit_HumanPlayerName->text().trimmed().toUtf8().constData());
@@ -685,7 +692,7 @@ void settingsDialogImpl::isAccepted()
 								  tr("The entered server list address is not a valid URL.\n"
 									 "Please enter a valid server list address!"),
 								  QMessageBox::Ok);
-			settingsCorrect = FALSE;
+			settingsCorrect = false;
 		}
 	}
 	if(groupBox_manualServerConfig->isChecked()) {
@@ -707,7 +714,7 @@ void settingsDialogImpl::isAccepted()
 	myConfig->writeConfigInt("UseInternetGamePassword", checkBox_UseInternetGamePassword->isChecked());
 	myConfig->writeConfigString("InternetGamePassword", lineEdit_InternetGamePassword->text().toUtf8().constData());
 	myConfig->writeConfigInt("UseLobbyChat", checkBox_UseLobbyChat->isChecked());
-	myConfig->writeConfigInt("NetAutoLeaveGameAfterFinish", checkBox_InetGane_AutoLeaveTheTableAfterGameFinished->isChecked());
+	myConfig->writeConfigInt("NetAutoLeaveGameAfterFinish", checkBox_InetGame_AutoLeaveTheTableAfterGameFinished->isChecked());
 	myConfig->writeConfigInt("InternetGameType", comboBox_internetGameType->currentIndex());
 	myConfig->writeConfigString("InternetGameName", lineEdit_internetGameName->text().toUtf8().constData());
 
@@ -717,7 +724,7 @@ void settingsDialogImpl::isAccepted()
 		playerIgnoreList.push_back(QString("%1").arg(treeWidget_internetGameIgnoredPlayers->topLevelItem(k)->text(0)).toUtf8().constData());
 	}
 	myConfig->writeConfigStringList("PlayerIgnoreList", playerIgnoreList);
-
+	myConfig->writeConfigInt("InternetGameAllowSpectators", checkBox_allowSpectators->isChecked());
 
 	// 	Interface
 	myConfig->writeConfigString("Language", comboBox_switchLanguage->itemData(comboBox_switchLanguage->currentIndex()).toString().toUtf8().constData());
@@ -732,10 +739,14 @@ void settingsDialogImpl::isAccepted()
 	myConfig->writeConfigInt("ShowCardsChanceMonitor", checkBox_cardsChanceMonitor->isChecked());
 	myConfig->writeConfigInt("AntiPeekMode", checkBox_antiPeekMode->isChecked());
 	myConfig->writeConfigInt("ShowCountryFlagInAvatar", checkBox_showCountryFlagInAvatar->isChecked());
+	myConfig->writeConfigInt("ShowPingStateInAvatar", checkBox_showPingStateInAvatar->isChecked());
 	myConfig->writeConfigInt("DontTranslateInternationalPokerStringsFromStyle", checkBox_dontTranslatePokerStrings->isChecked());
 	myConfig->writeConfigInt("DisableSplashScreenOnStartup", checkBox_disableSplashscreen->isChecked());
 	myConfig->writeConfigInt("EnableBetInputFocusSwitch", checkBox_enableBetInputFocusSwitch->isChecked());
 	myConfig->writeConfigInt("AccidentallyCallBlocker", checkBox_enableAccidentallyCallBlocker->isChecked());
+	myConfig->writeConfigInt("DontHideAvatarsOfIgnored", checkBox_dontHideAvatarsOfIgnored->isChecked());
+	myConfig->writeConfigInt("DisableChatEmoticons", checkBox_disableChatEmoticons->isChecked());
+
 	myConfig->writeConfigInt("FlipsideTux", radioButton_flipsideTux->isChecked());
 	myConfig->writeConfigInt("FlipsideOwn", radioButton_flipsideOwn->isChecked());
 
@@ -748,7 +759,7 @@ void settingsDialogImpl::isAccepted()
 								  tr("The entered flipside picture doesn't exist.\n"
 									 "Please enter an valid picture!"),
 								  QMessageBox::Ok);
-			settingsCorrect = FALSE;
+			settingsCorrect = false;
 		}
 	}
 
@@ -808,7 +819,7 @@ void settingsDialogImpl::isAccepted()
 								  tr("The log file directory doesn't exist.\n"
 									 "Please select an valid directory!"),
 								  QMessageBox::Ok);
-			settingsCorrect = FALSE;
+			settingsCorrect = false;
 		}
 
 		myConfig->writeConfigInt("LogStoreDuration", spinBox_logStoreDuration->value());
@@ -1014,7 +1025,7 @@ void settingsDialogImpl::callManualBlindsOrderDialog()
 	myManualBlindsOrderDialog->exec();
 	if(myManualBlindsOrderDialog->result() == QDialog::Accepted) {
 
-		bool ok = TRUE;
+		bool ok = true;
 		int i;
 		myManualBlindsList.clear();
 		for(i=0; i<myManualBlindsOrderDialog->listWidget_blinds->count(); i++) {
@@ -1050,7 +1061,7 @@ void settingsDialogImpl::callNetManualBlindsOrderDialog()
 	myManualBlindsOrderDialog->exec();
 	if(myManualBlindsOrderDialog->result() == QDialog::Accepted) {
 
-		bool ok = TRUE;
+		bool ok = true;
 		int i;
 		myNetManualBlindsList.clear();
 		for(i=0; i<myManualBlindsOrderDialog->listWidget_blinds->count(); i++) {
@@ -1106,21 +1117,21 @@ void settingsDialogImpl::setFirstSmallBlindMargin()
 void settingsDialogImpl::setLanguageChanged(int index)
 {
 
-	languageIsChanged = TRUE;
+	languageIsChanged = true;
 	changedLanguageIndex = index;
 
 }
 
 void settingsDialogImpl::toggleGroupBoxAutomaticServerConfig(bool toggleState)
 {
-	if(toggleState) groupBox_manualServerConfig->setChecked(FALSE);
-	else groupBox_manualServerConfig->setChecked(TRUE);
+	if(toggleState) groupBox_manualServerConfig->setChecked(false);
+	else groupBox_manualServerConfig->setChecked(true);
 }
 
 void settingsDialogImpl::toggleGroupBoxManualServerConfig(bool toggleState)
 {
-	if(toggleState) groupBox_automaticServerConfig->setChecked(FALSE);
-	else groupBox_automaticServerConfig->setChecked(TRUE);
+	if(toggleState) groupBox_automaticServerConfig->setChecked(false);
+	else groupBox_automaticServerConfig->setChecked(true);
 }
 
 void settingsDialogImpl::showCurrentGameTableStylePreview()
@@ -1156,7 +1167,7 @@ void settingsDialogImpl::showCurrentGameTableStylePreview()
 			maintainerEMailString = "<b>"+MaintainerEMail+":</b> "+style.getStyleMaintainerEMail()+"<br>";
 		}
 
-		label_gameTableStyleInfo->setWordWrap(TRUE);
+		label_gameTableStyleInfo->setWordWrap(true);
 		label_gameTableStyleInfo->setText("<b>"+MaintainerName+":</b> "+style.getStyleMaintainerName()+"<br>"+maintainerEMailString+"<b>"+CreateDate+":</b> "+style.getStyleCreateDate()+"<br>"+windowsSubString+"<br><b>"+State+": </b>"+style.getMyStateToolTipInfo());
 
 		//active the current selected item directly
@@ -1164,9 +1175,9 @@ void settingsDialogImpl::showCurrentGameTableStylePreview()
 
 		//disable remove button for distributed styles
 		if(item->data(0, 16).toInt() == POKERTH_DISTRIBUTED_STYLE) {
-			pushButton_removeGameTableStyle->setDisabled(TRUE);
+			pushButton_removeGameTableStyle->setDisabled(true);
 		} else {
-			pushButton_removeGameTableStyle->setDisabled(FALSE);
+			pushButton_removeGameTableStyle->setDisabled(false);
 		}
 
 	}
@@ -1201,11 +1212,11 @@ void settingsDialogImpl::addGameTableStyle()
 	if (!fileName.isEmpty()) {
 
 		int i;
-		bool fileNameAlreadyFound(FALSE);
+		bool fileNameAlreadyFound(false);
 		for(i=0; i < treeWidget_gameTableStyles->topLevelItemCount(); i++) {
 			QTreeWidgetItem *item = treeWidget_gameTableStyles->topLevelItem(i);
 			if(item->data(0, 15).toString() == fileName)
-				fileNameAlreadyFound = TRUE;
+				fileNameAlreadyFound = true;
 		}
 
 		if(fileNameAlreadyFound) {
@@ -1283,7 +1294,7 @@ void settingsDialogImpl::showCurrentCardDeckStylePreview()
 		}
 
 #ifdef GUI_800x480
-		label_cardDeckStyleInfo->setWordWrap(TRUE);
+		label_cardDeckStyleInfo->setWordWrap(true);
 #endif
 		label_cardDeckStyleInfo->setText("<b>"+MaintainerName+":</b> "+style.getStyleMaintainerName()+"<br>"+maintainerEMailString+"<b>"+CreateDate+":</b> "+style.getStyleCreateDate()+"");
 		//active the current selected item directly
@@ -1291,9 +1302,9 @@ void settingsDialogImpl::showCurrentCardDeckStylePreview()
 
 		//disable remove button for distributed styles
 		if(item->data(0, 16).toInt() == POKERTH_DISTRIBUTED_STYLE) {
-			pushButton_removeCardDeckStyle->setDisabled(TRUE);
+			pushButton_removeCardDeckStyle->setDisabled(true);
 		} else {
-			pushButton_removeCardDeckStyle->setDisabled(FALSE);
+			pushButton_removeCardDeckStyle->setDisabled(false);
 		}
 	}
 }
@@ -1327,11 +1338,11 @@ void settingsDialogImpl::addCardDeckStyle()
 	if (!fileName.isEmpty()) {
 
 		int i;
-		bool fileNameAlreadyFound(FALSE);
+		bool fileNameAlreadyFound(false);
 		for(i=0; i < treeWidget_cardDeckStyles->topLevelItemCount(); i++) {
 			QTreeWidgetItem *item = treeWidget_cardDeckStyles->topLevelItem(i);
 			if(item->data(0, 15).toString() == fileName)
-				fileNameAlreadyFound = TRUE;
+				fileNameAlreadyFound = true;
 		}
 
 		if(fileNameAlreadyFound) {
