@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 #ifndef CARDDECKSTYLEREADER_H
 #define CARDDECKSTYLEREADER_H
@@ -24,13 +37,14 @@
 #include <QtCore>
 #include <QtGui>
 
-#define POKERTH_CD_STYLE_FILE_VERSION	1
+#define POKERTH_CD_STYLE_FILE_VERSION	2
 
 enum CdStyleState {
 	CD_STYLE_OK = 0,
 	CD_STYLE_OUTDATED,
 	CD_STYLE_FIELDS_EMPTY,
 	CD_STYLE_PICTURES_MISSING,
+	CD_STYLE_UNDEFINED
 };
 
 class CardDeckStyleReader : public QObject
@@ -66,6 +80,10 @@ public:
 		return Preview;
 	}
 
+	QString getBigIndexesActionBottom() const {
+		return BigIndexesActionBottom;
+	}
+
 	bool getFallBack() const {
 		return fallBack;
 	}
@@ -73,8 +91,15 @@ public:
 		return loadedSuccessfull;
 	}
 
-	void showLeftItemsErrorMessage(QString, QStringList, QString);
-	void showCardsLeftErrorMessage(QString, QStringList, QString);
+	CdStyleState getState() const {
+		return myState;
+	}
+
+	QString getMyStateToolTipInfo();
+	void showErrorMessage();
+	void showLeftItemsErrorMessage();
+	void showCardsLeftErrorMessage();
+	void showOutdatedErrorMessage();
 
 private:
 
@@ -84,6 +109,7 @@ private:
 	QString StyleCreateDate;
 	QString PokerTHStyleFileVersion;
 	QString Preview;
+	QString BigIndexesActionBottom;
 
 	QString currentFileName;
 	QString currentDir;
@@ -97,6 +123,8 @@ private:
 
 	bool fallBack;
 	bool loadedSuccessfull;
+
+	CdStyleState myState;
 };
 
 #endif
