@@ -589,6 +589,9 @@ AbstractClientStateReceiving::HandlePacket(boost::shared_ptr<ClientThread> clien
 		case RemovedFromGameMessage::removedStartFailed :
 			removeReason = NTF_NET_REMOVED_START_FAILED;
 			break;
+		case RemovedFromGameMessage::gameClosed :
+			removeReason = NTF_NET_REMOVED_GAME_CLOSED;
+			break;
 		default :
 			removeReason = NTF_NET_REMOVED_ON_REQUEST;
 			break;
@@ -628,6 +631,29 @@ AbstractClientStateReceiving::HandlePacket(boost::shared_ptr<ClientThread> clien
 
 		boost::shared_ptr<PlayerData> playerData = client->CreatePlayerData(netPlayerJoined.playerid(), netPlayerJoined.isgameadmin());
 		client->AddPlayerData(playerData);
+	} else if (tmpPacket->GetMsg()->messagetype() == PokerTHMessage::Type_GameSpectatorJoinedMessage) {
+		// Another spectator joined the network game.
+		const GameSpectatorJoinedMessage &netSpectatorJoined = tmpPacket->GetMsg()->gamespectatorjoinedmessage();
+		// Request player info if needed.
+		PlayerInfo info;
+		if (!client->GetCachedPlayerInfo(netSpectatorJoined.playerid(), info)) {
+			client->RequestPlayerInfo(netSpectatorJoined.playerid());
+		}
+		client->ModifyGameInfoAddSpectatorDuringGame(netSpectatorJoined.playerid());
+	} else if (tmpPacket->GetMsg()->messagetype() == PokerTHMessage::Type_GameSpectatorLeftMessage) {
+		// A spectator left the network game.
+		const GameSpectatorLeftMessage &netSpectatorLeft = tmpPacket->GetMsg()->gamespectatorleftmessage();
+		// Signal to GUI and remove from data list.
+		int removeReason;
+		switch (netSpectatorLeft.gamespectatorleftreason()) {
+		case GamePlayerLeftMessage::leftKicked :
+			removeReason = NTF_NET_REMOVED_KICKED;
+			break;
+		default :
+			removeReason = NTF_NET_REMOVED_ON_REQUEST;
+			break;
+		}
+		client->ModifyGameInfoRemoveSpectatorDuringGame(netSpectatorLeft.playerid(), removeReason);
 	} else if (tmpPacket->GetMsg()->messagetype() == PokerTHMessage::Type_TimeoutWarningMessage) {
 		const TimeoutWarningMessage &tmpTimeout = tmpPacket->GetMsg()->timeoutwarningmessage();
 		client->GetCallback().SignalNetClientShowTimeoutDialog((NetTimeoutReason)tmpTimeout.timeoutreason(), tmpTimeout.remainingseconds());
@@ -672,15 +698,7 @@ AbstractClientStateReceiving::HandlePacket(boost::shared_ptr<ClientThread> clien
 		const PlayerListMessage &netPlayerList = tmpPacket->GetMsg()->playerlistmessage();
 
 		if (netPlayerList.playerlistnotification() == PlayerListMessage::playerListNew) {
-			PlayerInfo info;
-			if (!client->GetCachedPlayerInfo(netPlayerList.playerid(), info)) {
-				// Request player info.
-				ostringstream name;
-				name << "#" << netPlayerList.playerid();
-				info.playerName = name.str();
-				client->RequestPlayerInfo(netPlayerList.playerid());
-			}
-			client->GetCallback().SignalLobbyPlayerJoined(netPlayerList.playerid(), info.playerName);
+			client->GetCallback().SignalLobbyPlayerJoined(netPlayerList.playerid(), client->GetPlayerName(netPlayerList.playerid()));
 		} else if (netPlayerList.playerlistnotification() == PlayerListMessage::playerListLeft) {
 			client->GetCallback().SignalLobbyPlayerLeft(netPlayerList.playerid());
 		}
@@ -688,11 +706,11 @@ AbstractClientStateReceiving::HandlePacket(boost::shared_ptr<ClientThread> clien
 		// A new game was created on the server.
 		const GameListNewMessage &netListNew = tmpPacket->GetMsg()->gamelistnewmessage();
 
-		unsigned numPlayers = netListNew.playerids_size();
 		// Request player info for players if needed.
 		GameInfo tmpInfo;
 		list<unsigned> requestList;
-		for (unsigned i = 0; i < numPlayers; i++) {
+		// All players.
+		for (int i = 0; i < netListNew.playerids_size(); i++) {
 			PlayerInfo info;
 			unsigned playerId = netListNew.playerids(i);
 			if (!client->GetCachedPlayerInfo(playerId, info)) {
@@ -700,6 +718,15 @@ AbstractClientStateReceiving::HandlePacket(boost::shared_ptr<ClientThread> clien
 			}
 			tmpInfo.players.push_back(playerId);
 		}
+		// All spectators.
+		for (int i = 0; i < netListNew.spectatorids_size(); i++) {
+			PlayerInfo info;
+			unsigned playerId = netListNew.spectatorids(i);
+			if (!client->GetCachedPlayerInfo(playerId, info)) {
+				requestList.push_back(playerId);
+			}
+			tmpInfo.spectators.push_back(playerId);
+		}
 		// Send request for multiple players (will only act if list is non-empty).
 		client->RequestPlayerInfo(requestList);
 
@@ -730,6 +757,19 @@ AbstractClientStateReceiving::HandlePacket(boost::shared_ptr<ClientThread> clien
 		const GameListPlayerLeftMessage &netListLeft = tmpPacket->GetMsg()->gamelistplayerleftmessage();
 
 		client->ModifyGameInfoRemovePlayer(netListLeft.gameid(), netListLeft.playerid());
+	} else if (tmpPacket->GetMsg()->messagetype() == PokerTHMessage::Type_GameListSpectatorJoinedMessage) {
+		const GameListSpectatorJoinedMessage &netListJoined = tmpPacket->GetMsg()->gamelistspectatorjoinedmessage();
+
+		client->ModifyGameInfoAddSpectator(netListJoined.gameid(), netListJoined.playerid());
+		// Request player info if needed.
+		PlayerInfo info;
+		if (!client->GetCachedPlayerInfo(netListJoined.playerid(), info)) {
+			client->RequestPlayerInfo(netListJoined.playerid());
+		}
+	} else if (tmpPacket->GetMsg()->messagetype() == PokerTHMessage::Type_GameListSpectatorLeftMessage) {
+		const GameListSpectatorLeftMessage &netListLeft = tmpPacket->GetMsg()->gamelistspectatorleftmessage();
+
+		client->ModifyGameInfoRemoveSpectator(netListLeft.gameid(), netListLeft.playerid());
 	} else if (tmpPacket->GetMsg()->messagetype() == PokerTHMessage::Type_GameListAdminChangedMessage) {
 		const GameListAdminChangedMessage &netListAdmin = tmpPacket->GetMsg()->gamelistadminchangedmessage();
 
@@ -1220,6 +1260,7 @@ ClientStateWaitJoin::InternalHandlePacket(boost::shared_ptr<ClientThread> client
 		GameData tmpData;
 		NetPacket::GetGameData(netJoinAck.gameinfo(), tmpData);
 		client->SetGameData(tmpData);
+		client->ModifyGameInfoClearSpectatorsDuringGame();
 
 		// Player number is 0 on init. Will be set when the game starts.
 		boost::shared_ptr<PlayerData> playerData(
@@ -1730,6 +1771,9 @@ ClientStateRunHand::InternalHandlePacket(boost::shared_ptr<ClientThread> client,
 					client->GetClientLog()->transformPlayerActionLog(PlayerAction(netActionDone.playeraction())),
 					netActionDone.totalplayerbet() - tmpPlayer->getMySet()
 				);
+				if (tmpPlayer->getMyID() == 0) {
+					client->EndPing();
+				}
 			}
 			// Update last players turn only after the blinds.
 			curGame->getCurrentHand()->setPreviousPlayerID(tmpPlayer->getMyID());
