@@ -34,6 +34,7 @@
 #include <net/socket_helper.h>
 #include <net/serverlobbythread.h>
 #include <net/serveraccepthelper.h>
+#include <net/serveracceptwebhelper.h>
 #include <net/serverexception.h>
 #include <net/socket_msg.h>
 #include <net/socket_startup.h>
@@ -77,7 +78,8 @@ ServerManager::~ServerManager()
 }
 
 void
-ServerManager::Init(unsigned serverPort, bool ipv6, ServerTransportProtocol proto, const string &logDir)
+ServerManager::Init(unsigned serverPort, unsigned websocketPort, bool ipv6, int proto, const string &logDir,
+					const string &webSocketResource, const string &webSocketOrigin)
 {
 	GetLobbyThread().Init(logDir);
 
@@ -92,6 +94,12 @@ ServerManager::Init(unsigned serverPort, bool ipv6, ServerTransportProtocol prot
 			sctpAcceptHelper->Listen(serverPort, ipv6, logDir, m_lobbyThread);
 			m_acceptHelperPool.push_back(sctpAcceptHelper);
 		}*/
+	if (proto & TRANSPORT_PROTOCOL_WEBSOCKET) {
+		boost::shared_ptr<ServerAcceptInterface> webAcceptHelper(
+			new ServerAcceptWebHelper(GetGui(), m_ioService, webSocketResource, webSocketOrigin));
+		webAcceptHelper->Listen(websocketPort, ipv6, logDir, m_lobbyThread);
+		m_acceptHelperPool.push_back(webAcceptHelper);
+	}
 }
 
 void
