@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 /* Network server game. */
 
@@ -42,7 +55,8 @@ class ServerGame : public boost::enable_shared_from_this<ServerGame>
 {
 public:
 	ServerGame(
-		boost::shared_ptr<ServerLobbyThread> lobbyThread, u_int32_t id, const std::string &name, const std::string &pwd, const GameData &gameData, unsigned adminPlayerId, GuiInterface &gui, ConfigFile &playerConfig);
+		boost::shared_ptr<ServerLobbyThread> lobbyThread, u_int32_t id, const std::string &name, const std::string &pwd, const GameData &gameData,
+		unsigned adminPlayerId, unsigned creatorPlayerDBId, GuiInterface &gui, ConfigFile &playerConfig);
 	virtual ~ServerGame();
 
 	void Init();
@@ -50,8 +64,9 @@ public:
 
 	u_int32_t GetId() const;
 	const std::string &GetName() const;
+	unsigned GetCreatorDBId() const;
 
-	void AddSession(boost::shared_ptr<SessionData> session);
+	void AddSession(boost::shared_ptr<SessionData> session, bool spectateOnly);
 	void RemovePlayer(unsigned playerId, unsigned errorCode);
 	void MutePlayer(unsigned playerId, bool mute);
 	void MarkPlayerAsInactive(unsigned playerId);
@@ -62,9 +77,10 @@ public:
 	ServerCallback &GetCallback();
 	GameState GetCurRound() const;
 
-	void SendToAllPlayers(boost::shared_ptr<NetPacket> packet, SessionData::State state);
-	void SendToAllButOnePlayers(boost::shared_ptr<NetPacket> packet, SessionId except, SessionData::State state);
+	void SendToAllPlayers(boost::shared_ptr<NetPacket> packet, int state);
+	void SendToAllButOnePlayers(boost::shared_ptr<NetPacket> packet, SessionId except, int state);
 	void RemoveAllSessions();
+	void MoveSpectatorsToLobby();
 
 	bool IsPasswordProtected() const;
 	bool CheckPassword(const std::string &password) const;
@@ -73,6 +89,7 @@ public:
 
 	boost::shared_ptr<PlayerData> GetPlayerDataByUniqueId(unsigned playerId) const;
 	PlayerIdList GetPlayerIdList() const;
+	PlayerIdList GetSpectatorIdList() const;
 	bool IsPlayerConnected(const std::string &name) const;
 	bool IsPlayerConnected(unsigned playerId) const;
 	bool IsClientAddressConnected(const std::string &clientAddress) const;
@@ -96,6 +113,12 @@ public:
 	void AddReactivatePlayer(unsigned playerId);
 	PlayerIdList GetAndResetReactivatePlayers();
 
+	void AddNewSpectator(unsigned playerId);
+	PlayerIdList GetAndResetNewSpectators();
+
+	void SetNameReported();
+	bool IsNameReported() const;
+
 	// should be protected, but is needed in function.
 	const Game &GetGame() const;
 	Game &GetGame();
@@ -137,7 +160,7 @@ protected:
 	void ResetComputerPlayerList();
 
 	void RemoveSession(boost::shared_ptr<SessionData> session, int reason);
-	void RemovePlayerData(boost::shared_ptr<PlayerData> player, int reason);
+	void RemovePlayerData(boost::shared_ptr<PlayerData> player, int reason, bool spectateOnly);
 	void SessionError(boost::shared_ptr<SessionData> session, int errorCode);
 	void MoveSessionToLobby(boost::shared_ptr<SessionData> session, int reason);
 
@@ -187,6 +210,9 @@ private:
 	PlayerIdList m_reactivatePlayerList;
 	mutable boost::mutex m_reactivatePlayerListMutex;
 
+	PlayerIdList m_newSpectatorList;
+	mutable boost::mutex m_newSpectatorListMutex;
+
 	PlayerIdList m_reportedAvatarList;
 
 	RankingMap m_rankingMap;
@@ -207,12 +233,14 @@ private:
 	const u_int32_t		m_id;
 	const std::string	m_name;
 	const std::string	m_password;
+	const unsigned		m_creatorPlayerDBId;
 	ConfigFile		   &m_playerConfig;
 	unsigned			m_gameNum;
 	unsigned			m_curPetitionId;
 	boost::asio::deadline_timer m_voteKickTimer;
 	boost::asio::deadline_timer m_stateTimer1;
 	boost::asio::deadline_timer m_stateTimer2;
+	bool				m_isNameReported;
 
 	friend class ServerLobbyThread;
 	friend class AbstractServerGameStateReceiving;
