@@ -49,6 +49,7 @@ typedef unsigned SessionId;
 
 struct Gsasl;
 struct Gsasl_session;
+struct WebSocketData;
 class ReceiveBuffer;
 class SendBuffer;
 class NetPacket;
@@ -58,9 +59,10 @@ class ServerGame;
 class SessionData : public boost::enable_shared_from_this<SessionData>
 {
 public:
-	enum State { Init, ReceivingAvatar, Established, Game, Closed };
+	enum State { Init = 1, ReceivingAvatar = 2, Established = 4, Game = 8, Spectating = 16, SpectatorWaiting = 32, Closed = 128 };
 
 	SessionData(boost::shared_ptr<boost::asio::ip::tcp::socket> sock, SessionId id, SessionDataCallback &cb, boost::asio::io_service &ioService);
+	SessionData(boost::shared_ptr<WebSocketData> webData, SessionId id, SessionDataCallback &cb, boost::asio::io_service &ioService, int filler);
 	~SessionData();
 
 	SessionId GetId() const;
@@ -72,6 +74,7 @@ public:
 	void SetState(State state);
 
 	boost::shared_ptr<boost::asio::ip::tcp::socket> GetAsioSocket();
+	boost::shared_ptr<WebSocketData> GetWebData();
 
 	bool CreateServerAuthSession(Gsasl *context);
 	bool CreateClientAuthSession(Gsasl *context, const std::string &userName, const std::string &password);
@@ -102,6 +105,8 @@ public:
 	void Close() {
 		m_callback.CloseSession(shared_from_this());
 	}
+	void CloseSocketHandle();
+	void CloseWebSocketHandle();
 	void HandlePacket(boost::shared_ptr<NetPacket> packet) {
 		m_callback.HandlePacket(shared_from_this(), packet);
 	}
@@ -116,6 +121,8 @@ public:
 	void SetPlayerData(boost::shared_ptr<PlayerData> player);
 	boost::shared_ptr<PlayerData> GetPlayerData();
 
+	std::string GetRemoteIPAddressFromSocket() const;
+
 protected:
 	SessionData(const SessionData &other);
 	SessionData &operator=(const SessionData &other);
@@ -125,7 +132,8 @@ protected:
 	void TimerActivityWarning(const boost::system::error_code &ec);
 
 private:
-	boost::shared_ptr<boost::asio::ip::tcp::socket> m_socket;
+	boost::shared_ptr<boost::asio::ip::tcp::socket>	m_socket;
+	boost::shared_ptr<WebSocketData>	m_webData;
 	const SessionId					m_id;
 	boost::weak_ptr<ServerGame>		m_game;
 	State							m_state;
