@@ -1,6 +1,6 @@
 /*****************************************************************************
  * PokerTH - The open source texas holdem engine                             *
- * Copyright (C) 2006-2011 Felix Hammer, Florian Thauer, Lothar May          *
+ * Copyright (C) 2006-2012 Felix Hammer, Florian Thauer, Lothar May          *
  *                                                                           *
  * This program is free software: you can redistribute it and/or modify      *
  * it under the terms of the GNU Affero General Public License as            *
@@ -14,6 +14,19 @@
  *                                                                           *
  * You should have received a copy of the GNU Affero General Public License  *
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
+ *                                                                           *
+ *                                                                           *
+ * Additional permission under GNU AGPL version 3 section 7                  *
+ *                                                                           *
+ * If you modify this program, or any covered work, by linking or            *
+ * combining it with the OpenSSL project's OpenSSL library (or a             *
+ * modified version of that library), containing parts covered by the        *
+ * terms of the OpenSSL or SSLeay licenses, the authors of PokerTH           *
+ * (Felix Hammer, Florian Thauer, Lothar May) grant you additional           *
+ * permission to convey the resulting work.                                  *
+ * Corresponding Source for a non-source form of such a combination          *
+ * shall include the source code for the parts of OpenSSL used as well       *
+ * as that of the covered work.                                              *
  *****************************************************************************/
 /* Socket helper defines. */
 #ifndef _SOCKET_HELPER_H_
@@ -21,15 +34,12 @@
 
 #ifdef _WIN32
 
-#ifdef __GNUC__ /* mingw provides stdint.h */
 #include <stdint.h>
 typedef uint16_t					u_int16_t;
 typedef uint32_t					u_int32_t;
-#else
-typedef unsigned __int16			u_int16_t;
-typedef unsigned __int32			u_int32_t;
-typedef __int16						int16_t;
-typedef __int32						int32_t;
+#ifndef __GNUC__ /* ssize_t not defined in MSVC */
+typedef _W64 int					ssize_t;
+#define _SSIZE_T_
 #endif
 
 typedef unsigned char					u_char;
