@@ -116,6 +116,7 @@
 #define NTF_NET_REMOVED_KICKED			205
 #define NTF_NET_REMOVED_TIMEOUT			206
 #define NTF_NET_REMOVED_START_FAILED	207
+#define NTF_NET_REMOVED_GAME_CLOSED		208
 
 // Notifications - join failed
 #define NTF_NET_JOIN_GAME_INVALID		210
@@ -129,10 +130,11 @@
 #define NTF_NET_JOIN_INVALID_SETTINGS	218
 #define NTF_NET_JOIN_IP_BLOCKED			219
 #define NTF_NET_JOIN_REJOIN_FAILED		220
+#define NTF_NET_JOIN_NO_SPECTATORS		221
 
 // Notifications - version
-#define NTF_NET_NEW_RELEASE_AVAILABLE	221
-#define NTF_NET_OUTDATED_BETA			222
+#define NTF_NET_NEW_RELEASE_AVAILABLE	231
+#define NTF_NET_OUTDATED_BETA			232
 
 // This is an internal message which is not reported.
 #define MSG_SOCK_INTERNAL_PENDING		0
