@@ -113,9 +113,12 @@ public:
 
 	void reportBadAvatar(unsigned reportedPlayerId, const std::string &avatarHash);
 	void reportBadGameName(unsigned gameId);
+	void adminActionBanPlayer(unsigned playerId);
 
 	void resetNetworkTimeout();
 
+	void adminActionCloseGame(unsigned gameId);
+
 	bool isNetworkClientRunning() const; // TODO hack
 	bool isNetworkServerRunning() const; // TODO hack
 
